import { Version } from '@microsoft/sp-core-library';
import {
  BaseClientSideWebPart,
  IPropertyPaneConfiguration,
  PropertyPaneTextField
} from '@microsoft/sp-webpart-base';
import { escape } from '@microsoft/sp-lodash-subset';

import styles from './ZhPnPjsWebPart.module.scss';
import * as strings from 'ZhPnPjsWebPartStrings';


import { sp } from "@pnp/sp";
import { dateAdd } from "@pnp/common";

export interface IZhPnPjsWebPartProps {
  description: string;
}

export default class ZhPnPjsWebPart extends BaseClientSideWebPart<IZhPnPjsWebPartProps> {

  public render(): void {
//#region - Setup
    let resultsHTML = '';
    let expireDate: Date = new Date();
    expireDate.setDate(expireDate.getDate() + 1);

    sp.setup({
      spfxContext: this.context
    });
//#endregion


    // get all the items from a list
    sp.web.lists.getByTitle("CommunityContributors").items.select('Title', 'Twitter', 'Blog').orderBy('Created', true)
    
    
      .usingCaching({
        expiration: expireDate,
        key: "zhFirstGearListData",
        storeName: "session" // or "local"
      })

      .get().then((items: any[]) => {
        this.domElement.innerHTML = this.generateHTML(items);
      });
  }

  public generateHTML(listItems): any {

    let html: string = '';

    for (let i = 0; i < listItems.length; i++) {
      let contributor = listItems[i];

      console.log(contributor);
      let itemHTML = `
        <div class="${styles["singleCommunityMember"]}">
          <div class="${styles["communityMemberInner"]}">
            <div class="${styles["communityMemberBiopic"]}"> 
              <span>
                <img src="https://avatars.io/twitter/${contributor.Twitter}"/>
              </span> 
            </div>
            <div class="${styles["communityMemberSocialDetails"]}">
              <h4 class="${styles["communityMemberSocialDetails-name"]}">${contributor.Title}</h4>
              <p class="${styles["communityMemberSocialTwitterWrapper"]}"><span class="socialLabelTwitter">Twitter:</span> <a href="https://www.twitter.com/${contributor.Twitter}" target="_blank">@${contributor.Twitter}</a></p>
              <p class="${styles["communityMemberSocialBlogWrapper"]}"><span class="socialLabelBlog">Blog:</span> <a href="${contributor.Blog}" target="_blank">${contributor.Blog}</a></p>
            </div>
          </div>
        </div>
      `;
      html += itemHTML;
    }

    return html;



  }

  protected get dataVersion(): Version {
    return Version.parse('1.0');
  }

  protected getPropertyPaneConfiguration(): IPropertyPaneConfiguration {
    return {
      pages: [
        {
          header: {
            description: strings.PropertyPaneDescription
          },
          groups: [
            {
              groupName: strings.BasicGroupName,
              groupFields: [
                PropertyPaneTextField('description', {
                  label: strings.DescriptionFieldLabel
                })
              ]
            }
          ]
        }
      ]
    };
  }
}
