import { Version } from '@microsoft/sp-core-library';
import {
  BaseClientSideWebPart,
  IPropertyPaneConfiguration,
  PropertyPaneTextField
} from '@microsoft/sp-webpart-base';
import { escape } from '@microsoft/sp-lodash-subset';

import styles from './ZhLibraryComponentWebPartWebPart.module.scss';
import * as strings from 'ZhLibraryComponentWebPartWebPartStrings';

import * as libraryComponent from 'zh-library-component';

export interface IZhLibraryComponentWebPartWebPartProps {
  description: string;
}

export default class ZhLibraryComponentWebPartWebPart extends BaseClientSideWebPart<IZhLibraryComponentWebPartWebPartProps> {

  public render(): void {

    this.domElement.innerHTML = `
    <div class="${ styles.zhLibraryComponentWebPart}">
    <div class="${ styles.container}">
      <div class="${ styles.row}">
        <div class="${ styles.column}">
          <span class="${ styles.title}">Community Contributors</span>
          <p class="${ styles.subTitle}">How many contributors would you like to see?
            <select id=${styles.communitySelect} class="${styles.communitySelectStyles}">
              <option value="1">1</option>
              <option value="2">2</option>
              <option value="3">3</option>
              <option value="4">4</option>
              <option value="5">5</option>
              <option value="6">6</option>
              <option value="7">7</option>
              <option value="8">8</option>
              <option value="9">9</option>
              <option value="10">10</option>
            </select>
          </p>
          <a href="#" class="${ styles.button}">
            <span class="${ styles.label}">Retrieve Contributors</span>
          </a>
        </div>
      </div>
    </div>
  </div>
  <div id="${styles.communityContributorsWrapper}"></div>`;

  let btn = document.getElementsByClassName(styles.button);
  for (let button of btn as any) {
    button.addEventListener("click", (e: Event) => this.requestListItems());
  }
  }


    protected requestListItems() {
    //#region - Obtain Coummunity Count
    // Normally you would not use an ID in a web part. This is used to keep the demo simple.
    let e = (document.getElementById(styles.communitySelect)) as HTMLSelectElement;
    let sel = e.selectedIndex;
    let opt = e.options[sel];
    let value:any = opt.value;
    //#endregion 

      const libCompInstance = new libraryComponent.ZhLibraryComponentLibrary();  
      let pnpjs:any = libCompInstance.importPNPJS();
      pnpjs.sp.setup({
        spfxContext: this.context
      });

      pnpjs.sp.web.lists.getByTitle("CommunityContributors").items.select('Title', 'Twitter', 'Blog').orderBy('Created', true).top(opt.value).get().then((items: any[]) => {
        console.log(items);
        this.generateHTML(items);

      });
    }

  public generateHTML(listItems): any {

    let html: string = '';

    for (let i = 0; i < listItems.length; i++) {
      let contributor = listItems[i];

      console.log(contributor);
      let itemHTML = `
        <div class="${styles["singleCommunityMember"]}">
          <div class="${styles["communityMemberInner"]}">
            <div class="${styles["communityMemberBiopic"]}"> 
              <span>
                <img src="https://avatars.io/twitter/${contributor.Twitter}"/>
              </span> 
            </div>
            <div class="${styles["communityMemberSocialDetails"]}">
              <h4 class="${styles["communityMemberSocialDetails-name"]}">${contributor.Title}</h4>
              <p class="${styles["communityMemberSocialTwitterWrapper"]}"><span>Twitter:</span> <a href="https://www.twitter.com/${contributor.Twitter}" target="_blank">@${contributor.Twitter}</a></p>
              <p class="${styles["communityMemberSocialBlogWrapper"]}"><span>Blog:</span> <a href="${contributor.Blog}" target="_blank">${contributor.Blog}</a></p>
            </div>
          </div>
        </div>
      `;
      html += itemHTML;

    }

    document.getElementById(styles.communityContributorsWrapper).innerHTML = html;
    //return html;



  }

  protected get dataVersion(): Version {
    return Version.parse('1.0');
  }

  protected getPropertyPaneConfiguration(): IPropertyPaneConfiguration {
    return {
      pages: [
        {
          header: {
            description: strings.PropertyPaneDescription
          },
          groups: [
            {
              groupName: strings.BasicGroupName,
              groupFields: [
                PropertyPaneTextField('description', {
                  label: strings.DescriptionFieldLabel
                })
              ]
            }
          ]
        }
      ]
    };
  }
}
